#ifndef __E_TABLE_DEFINES__
#define __E_TABLE_DEFINES__ 1

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#define BUTTON_HEIGHT        10
#define BUTTON_PADDING       2
#define GROUP_INDENT         (BUTTON_HEIGHT + (BUTTON_PADDING * 2))

/* Padding around the contents of a header button */
#define HEADER_PADDING 1

#define MIN_ARROW_SIZE 10

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif
