#ifndef _E_TABLE_COL_DND_H_
#define _E_TABLE_COL_DND_H_

BEGIN_GNOME_DECLS

#define TARGET_ETABLE_COL_TYPE "application/x-etable-column-header"

enum {
	TARGET_ETABLE_COL_HEADER
};

END_GNOME_DECLS

#endif /* _E_TABLE_COL_DND_H_ */
