/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
#ifndef _E_CATEGORIES_MASTER_LIST_DIALOG_MODEL_H_
#define _E_CATEGORIES_MASTER_LIST_DIALOG_MODEL_H_

#include <gal/e-table/e-table-model.h>
#include <gal/widgets/e-categories-master-list.h>

#define E_CATEGORIES_MASTER_LIST_DIALOG_MODEL_TYPE        (e_categories_master_list_dialog_model_get_type ())
#define E_CATEGORIES_MASTER_LIST_DIALOG_MODEL(o)          (GTK_CHECK_CAST ((o), E_CATEGORIES_MASTER_LIST_DIALOG_MODEL_TYPE, ECategoriesMasterListDialogModel))
#define E_CATEGORIES_MASTER_LIST_DIALOG_MODEL_CLASS(k)    (GTK_CHECK_CLASS_CAST((k), E_CATEGORIES_MASTER_LIST_DIALOG_MODEL_TYPE, ECategoriesMasterListDialogModelClass))
#define E_IS_CATEGORIES_MASTER_LIST_DIALOG_MODEL(o)       (GTK_CHECK_TYPE ((o), E_CATEGORIES_MASTER_LIST_DIALOG_MODEL_TYPE))
#define E_IS_CATEGORIES_MASTER_LIST_DIALOG_MODEL_CLASS(k) (GTK_CHECK_CLASS_TYPE ((k), E_CATEGORIES_MASTER_LIST_DIALOG_MODEL_TYPE))

typedef struct ECategoriesMasterListDialogModelPriv  ECategoriesMasterListDialogModelPriv;

typedef struct ECategoriesMasterListDialogModel      ECategoriesMasterListDialogModel;
typedef struct ECategoriesMasterListDialogModelClass ECategoriesMasterListDialogModelClass;

struct ECategoriesMasterListDialogModel {
	ETableModel parent;

	ECategoriesMasterListDialogModelPriv *priv;
};


struct ECategoriesMasterListDialogModelClass {
	ETableModelClass parent_class;
};


GtkType      e_categories_master_list_dialog_model_get_type  (void);
ETableModel *e_categories_master_list_dialog_model_new       (void);

#endif /* _E_CATEGORIES_MASTER_LIST_DIALOG_MODEL_H_ */
